@@ -31,4 +31,4 @@ function test_polybspline()
 end
 
 test_polybspline()
-println("...finished polybpline() test")
\ No newline at end of file
+println("...finished polybspline test")
\ No newline at end of file
